@@ -842,6 +842,24 @@ def test_folium(pyi_builder):
         """)
 
 
+@importorskip("comtypes")
+@pytest.mark.skipif(not is_win, reason="comtypes is Windows only")
+def test_comtypes_stream(pyi_builder):
+    pyi_builder.test_source("""
+        import pathlib
+        import sys
+        import comtypes.client
+
+        module = comtypes.client.GetModule("shdocvw.dll")
+
+        try:
+            pathlib.Path(module.__file__).relative_to(sys._MEIPASS)
+            raise SystemExit(f"Error: comtypes is writing inside the application: {module.__file__}")
+        except ValueError:
+            pass
+    """)
+
+
 @importorskip("metpy")
 def test_metpy(pyi_builder):
     # Import metpy.plots, which triggers search for colortables data.
@@ -2008,6 +2026,19 @@ def test_xarray(pyi_builder):
     """)
 
 
+# Shows that we need to collect `xarray.chunkmanagers` entry point.
+# See: https://github.com/pyinstaller/pyinstaller/issues/8786
+@importorskip('xarray')
+@importorskip('dask')  # requires dask for default 'dask' chunk manager to become available
+def test_xarray_chunk(pyi_builder):
+    pyi_builder.test_source("""
+        import xarray as xr
+        import numpy as np
+
+        v = xr.Variable(dims=("T",), data=np.random.randn(10)).chunk()
+    """)
+
+
 @importorskip('tables')
 def test_pytables(pyi_builder):
     # NOTE: run_from_path=True prevents `pyi_builder` from completely clearing the `PATH` environment variable. At the
@@ -2034,11 +2065,15 @@ def test_schwifty(pyi_builder):
     """)
 
 
-@importorskip('gribapi')
+@importorskip('eccodes')
 def test_eccodes_gribapi(pyi_builder):
     pyi_builder.test_source("""
         import sys
         import os
+        import pathlib
+
+        # With eccodes 2.37.0, eccodes needs to be imported before gribapi to avoid circular imports.
+        import eccodes
 
         # Basic import test
         import gribapi
@@ -2046,12 +2081,31 @@ def test_eccodes_gribapi(pyi_builder):
         # Ensure that the eccodes shared library is bundled with the frozen application.
         import gribapi.bindings
 
-        lib_filename = os.path.join(
-            sys._MEIPASS,
-            os.path.basename(gribapi.bindings.library_path),
-        )
+        print(f"gribapi.bindings.library_path={gribapi.bindings.library_path}")
 
-        assert os.path.isfile(lib_filename), f"Shared library {lib_filename!s} not found!"
+        library_path = gribapi.bindings.library_path
+        if os.path.basename(library_path) == library_path:
+            # Only library basename is given - assume this is a system-wide copy that was collected
+            # into top-level application directory and loaded via `findlibs.find()`/`ctypes`.
+            expected_library_file = os.path.join(
+                sys._MEIPASS,
+                library_path,
+            )
+            if not os.path.isfile(expected_library_file):
+                raise RuntimeError(f"Shared library {expected_library_file!s} not found!")
+        else:
+            # Absolute path; check that it is rooted in top-level application directory. This covers all valid locations
+            # as per https://github.com/ecmwf/eccodes-python/blob/2.37.0/gribapi/bindings.py#L61-L64,
+            #  - sys._MEIPASS/eccodes
+            #  - sys._MEIPASS/eccodes.libs
+            #  - sys._MEIPASS/eccodes/.dylibs
+            # as well as sys._MEIPASS itself (in case system-wide copy was collected into top-level application
+            # directory but is reported with full path instead of just basename due to our override of `findlibs.find()`
+            # via run-time hook).
+            if pathlib.PurePath(sys._MEIPASS) not in pathlib.PurePath(library_path).parents:
+                raise RuntimeError(
+                    f"Shared library path {library_path} is not rooted in top-level application directory!"
+                )
     """)
 
 
@@ -2150,3 +2204,61 @@ def test_itk(pyi_builder):
     pyi_builder.test_source("""
         import itk
     """)
+
+
+@importorskip('slixmpp')
+def test_slixmpp(pyi_builder):
+    pyi_builder.test_source("""
+        import slixmpp
+        slixmpp.ClientXMPP('username', 'password')
+    """)
+
+
+@importorskip('capstone')
+def test_capstone(pyi_builder):
+    pyi_builder.test_source("""
+        import capstone
+        capstone.__version__
+    """)
+
+
+@importorskip('yapf')
+def test_yapf(pyi_builder):
+    pyi_builder.test_source("""
+        import yapf
+    """)
+
+
+@importorskip('grapheme')
+def test_grapheme(pyi_builder):
+    pyi_builder.test_source("""
+        import grapheme
+    """)
+
+
+@importorskip('xmlschema')
+def test_xmlschema(pyi_builder):
+    pyi_builder.test_source("""
+        import xmlschema
+    """)
+
+
+@importorskip('saml2')
+def test_saml2(pyi_builder):
+    pyi_builder.test_source("""
+        # this loads XSD files
+        import saml2.xml.schema
+
+        # this loads submodules from saml2.attributemap
+        from saml2.attribute_converter import ac_factory
+        ac_factory()
+    """)
+
+
+@importorskip('toga')
+def test_toga(pyi_builder):
+    pyi_builder.test_script(
+        "pyi_toga_app.py",
+        app_args=['--automatic-shutdown', '5'],
+        pyi_args=['--windowed'] if is_darwin else [],
+    )
